@@ -8,14 +8,14 @@
 
 #include "secure.h"
 
-#include <ksud_debug.h>
 #include <config-kdesud.h>
+#include <ksud_debug.h>
 
-#include <stdio.h>
-#include <unistd.h>
+#include <cerrno>
 #include <fcntl.h>
+#include <stdio.h>
 #include <string.h>
-#include <errno.h>
+#include <unistd.h>
 
 #include <sys/stat.h>
 
@@ -29,22 +29,28 @@ typedef unsigned ksocklen_t;
 
 #if defined(HAVE_GETPEEREID)
 
-SocketSecurity::SocketSecurity(int sockfd) : pid(-1), gid(-1), uid(-1)
+SocketSecurity::SocketSecurity(int sockfd)
+    : pid(-1)
+    , gid(-1)
+    , uid(-1)
 {
     uid_t euid;
     gid_t egid;
     if (getpeereid(sockfd, &euid, &egid) == 0) {
-	uid = euid;
-	gid = egid;
-	pid = -1;
+        uid = euid;
+        gid = egid;
+        pid = -1;
     }
 }
 
-# elif defined(HAVE_GETPEERUCRED)
+#elif defined(HAVE_GETPEERUCRED)
 
 #include <ucred.h>
 
-SocketSecurity::SocketSecurity(int sockfd) : pid(-1), gid(-1), uid(-1)
+SocketSecurity::SocketSecurity(int sockfd)
+    : pid(-1)
+    , gid(-1)
+    , uid(-1)
 {
     ucred_t *ucred = 0;
 
@@ -58,20 +64,23 @@ SocketSecurity::SocketSecurity(int sockfd) : pid(-1), gid(-1), uid(-1)
 
 #elif defined(SO_PEERCRED)
 
-SocketSecurity::SocketSecurity(int sockfd) : pid(-1), gid(-1), uid(-1)
+SocketSecurity::SocketSecurity(int sockfd)
+    : pid(-1)
+    , gid(-1)
+    , uid(-1)
 {
     ucred cred;
     ksocklen_t len = sizeof(struct ucred);
     if (getsockopt(sockfd, SOL_SOCKET, SO_PEERCRED, &cred, &len) < 0) {
         qCCritical(KSUD_LOG) << "getsockopt(SO_PEERCRED) " << strerror(errno);
-	return;
+        return;
     }
     pid = cred.pid;
     gid = cred.gid;
     uid = cred.uid;
 }
 
-# else
+#else
 #ifdef __GNUC__
 #warning SocketSecurity support for your platform not implemented/available!
 #endif
@@ -79,13 +88,16 @@ SocketSecurity::SocketSecurity(int sockfd) : pid(-1), gid(-1), uid(-1)
  * The default version does nothing.
  */
 
-SocketSecurity::SocketSecurity(int sockfd) : pid(-1), gid(-1), uid(-1)
+SocketSecurity::SocketSecurity(int sockfd)
+    : pid(-1)
+    , gid(-1)
+    , uid(-1)
 {
     static bool warned_him = false;
 
     if (!warned_him) {
-        qCWarning(KSUD_LOG) << "Using void socket security. Please add support for your" ;
-        qCWarning(KSUD_LOG) << "platform to src/kdesud/secure.cpp" ;
+        qCWarning(KSUD_LOG) << "Using void socket security. Please add support for your";
+        qCWarning(KSUD_LOG) << "platform to src/kdesud/secure.cpp";
         warned_him = true;
     }
 
